##parameters=id
##title=Copy Facets To Obect Types
import string
inheritedObjectTypes=[]
FacetTypes = context.Data.FacetTypes.objectIds( )
#PATH = string.replace( context.surl, container.REQUEST['BASE0'], '')
PATH = context.getInstancePath()
PATH = PATH + '/Data/'
Type1 = ['float','int','long']
Type2 = ['boolean']
Type3 = ['lines','string','text','tokens','selection','multiple selection']
#Type4 = ['date']

newObject = context.restrictedTraverse( PATH + 'ObjectType/' + id )
inheritedObjectTypes = newObject.getProperty('TTList')

for x in inheritedObjectTypes:
    if x != 'Object':
     ObjType = context.restrictedTraverse( PATH + 'ObjectType/' + x )
     ObjTypeProperty = ObjType.propertyIds( )
     for y in ObjTypeProperty:
        if y in FacetTypes:
           if y not in newObject.propertyIds( ):
              facetType = context.restrictedTraverse(PATH + 'FacetTypes/' + y)
              facetDataType = facetType.getProperty('datatype')
	      if facetDataType in Type1:
                 defFacetValue = 0
              elif facetDataType in Type2:
                 defFacetValue = 0
              elif facetDataType in Type3:
                 defFacetValue = ''
              #elif facetDataType in Type4:
                 #defFacetValue = DateTime()
              newObject.manage_addProperty( y, defFacetValue, facetDataType)
